# generated by datamodel-codegen:
#   filename:  aws-cfn-kafka-admin-provider-schema.json
#   timestamp: 2021-04-07T06:45:52+00:00

from __future__ import annotations

from enum import Enum
from typing import Any, Dict, List, Optional

from pydantic import BaseModel, Field, constr


class SecurityProtocol(Enum):
    PLAINTEXT = "PLAINTEXT"
    SSL = "SSL"
    SASL_PLAINTEXT = "SASL_PLAINTEXT"
    SASL_SSL = "SASL_SSL"


class SASLMechanism(Enum):
    PLAIN = "PLAIN"
    GSSAPI = "GSSAPI"
    OAUTHBEARER = "OAUTHBEARER"
    SCRAM_SHA_256 = "SCRAM-SHA-256"
    SCRAM_SHA_512 = "SCRAM-SHA-512"


class EwsKafkaParmeters(BaseModel):
    BootstrapServers: Optional[str] = Field(
        None,
        description="Endpoint URL of the Kafka cluster in the format hostname:port",
    )
    SecurityProtocol: Optional[SecurityProtocol] = Field(
        "PLAINTEXT", description="Kafka Security Protocol."
    )
    SASLMechanism: Optional[SASLMechanism] = Field(
        "PLAIN", description="Kafka SASL mechanism for Authentication"
    )
    SASLUsername: Optional[str] = Field(
        "", description="Kafka SASL username for Authentication"
    )
    SASLPassword: Optional[str] = Field(
        "", description="Kafka SASL password for Authentication"
    )


class PatternType(Enum):
    LITERAL = "LITERAL"
    PREFIXED = "PREFIXED"
    MATCH = "MATCH"


class ResourceType(Enum):
    CLUSTER = "CLUSTER"
    DELEGATION_TOKEN = "DELEGATION_TOKEN"
    GROUP = "GROUP"
    TOPIC = "TOPIC"
    TRANSACTIONAL_ID = "TRANSACTIONAL_ID"


class Action(Enum):
    ALL = "ALL"
    READ = "READ"
    WRITE = "WRITE"
    CREATE = "CREATE"
    DELETE = "DELETE"
    ALTER = "ALTER"
    DESCRIBE = "DESCRIBE"
    CLUSTER_ACTION = "CLUSTER_ACTION"
    DESCRIBE_CONFIGS = "DESCRIBE_CONFIGS"
    ALTER_CONFIGS = "ALTER_CONFIGS"
    IDEMPOTENT_WRITE = "IDEMPOTENT_WRITE"


class Effect(Enum):
    DENY = "DENY"
    ALLOW = "ALLOW"


class Policy(BaseModel):
    Resource: constr(regex=r"^[a-zA-Z0-9_.-]+$") = Field(
        ..., description="Name of the resource to apply the ACL for"
    )
    PatternType: Optional[PatternType] = Field("LITERAL", description="Pattern type")
    Principal: str = Field(..., description="Kafka user to apply the ACLs for.")
    ResourceType: ResourceType = Field(
        ..., description="Kafka user to apply the ACLs for."
    )
    Action: Action = Field(..., description="Access action allowed.")
    Effect: Effect = Field(..., description="Effect for the ACL.")
    Host: Optional[str] = Field(
        "*", description="Specify the host for the ACL. Defaults to '*'"
    )


class EwsKafkaTopic(BaseModel):
    Name: Optional[constr(regex=r"^[a-zA-Z0-9_.-]+$", min_length=1)] = Field(
        None, description="Kafka topic name"
    )
    PartitionsCount: Optional[int] = Field(
        1, description="Number of partitions for the new Kafka topic"
    )
    ReplicationFactor: Optional[int] = Field(
        3, description="Kafka topic replication factor"
    )
    Settings: Optional[Dict[str, Any]] = None


class ReplicationFactor(BaseModel):
    __root__: int = Field(..., description="Kafka topic replication factor")


class ACLs(BaseModel):
    Policies: Optional[List[Policy]] = None
    FunctionName: Optional[str] = Field(
        None,
        description="Name or ARN of the Lambda function to use for Custom::KafkaACL",
    )


class Topics(BaseModel):
    Topics: Optional[List[EwsKafkaTopic]] = None
    ReplicationFactor: Optional[ReplicationFactor] = None
    FunctionName: Optional[str] = Field(
        None,
        description="Name or ARN of the Lambda function to use for Custom::KafkaTopic",
    )


class Model(BaseModel):
    Globals: EwsKafkaParmeters
    Topics: Optional[Topics] = None
    ACLs: Optional[ACLs] = None
